% ----------------------
% SS.m
% ----------------------
% computes steady state and fills the values for year 't'
% in:   DF,w,taxinstrument
% out:  resid
% ----------------------

function resid = SS(inputs)

global t rho g G gam omega sigma rho2 psi
global Y Div w theta I J V K Hv A Omegav Lambda Upsilon Q C TB DF edy r
global A_0 alpha LS LD edl ell N NB Nv delta Av Cv Omegav0 DF0
global epsl parl0 parl1 parp0 epsp hcut part ybar sharev yv hv
global tauW tauF taul tauprof tauprofdeduct tauC b p
global pc TaxF Exp Rev PB DG cG CG DGtarget edg budget_bal
global w0 tauW0 tauF0 tauprof0 taul0 cG0 eda edv tauC0

DF(t)    = DF0*inputs(1);
w(t)     = w0*inputs(2);

% budget-instrument choice
if budget_bal == 1; tauW(t) = tauW0*inputs(3); end
if budget_bal == 2; tauF(t) = tauF0*inputs(3); end
if budget_bal == 3; tauC(t) = tauC0*inputs(3); end
if budget_bal == 4; taul(t) = taul0*inputs(3); end
if budget_bal == 5; tauprof(t) = tauprof0*inputs(3); end
if budget_bal == 6; cG(t) = cG0*inputs(3); end

Omegav(1,t) = Omegav0(1)*inputs(4);

DG(t)    = DGtarget(t); % debt-rule

pc(t)    = 1+tauC(t);

% DEMOGRAPHY
Nv(1,t)  = NB(t)/(1-gam(1,t)*omega);
Nv(2,t)  = gam(1,t)*(1-omega)/(1-gam(2,t))*Nv(1,t);
N(t)     = sum(Nv(:,t));

CG(t)    = cG(t)*N(t);

% HOURS SUPPLY
ell(t)   = (((1-tauW(t))*w(t)*theta(t)/pc(t))/parl0)^epsl;
dis_ell  = parl0*(epsl/(1+epsl))*ell(t)^((1+epsl)/epsl)-parl1;

% PARTICIPATION
hcut(t)  = ((1-tauW(t))*w(t)*ell(t)*theta(t)-b(t))/pc(t)-dis_ell;
part(t)  = 1-hcut(t)^(-epsp)*parp0^epsp;
hexp     = 1/part(t)*epsp/(1+epsp)*(parp0^epsp*hcut(t)^(1-epsp)-parp0);
dis_tot  = part(t)*dis_ell-(1-part(t))*hexp;

% TOTAL LABOR SUPPLY
LS(t)    = part(t)*ell(t)*theta(t)*Nv(1,t);

% PRODUCTION
uck      = (r(t)+delta*(1-tauprofdeduct(t)*tauprof(t)))/(1-tauprof(t));
K(t)     = LS(t)*(alpha*A_0/uck)^(1/(1-alpha));
Y(t)     = A_0*K(t)^alpha*LS(t)^(1-alpha);
LD(t)    = Y(t)*(1-alpha)/((1+tauF(t))*w(t));

% INVESTMENT
I(t)     = (delta+g)*K(t);
J(t)     = 1/2*psi*K(t)*(I(t)/K(t)-delta-g)^2;

% FIRM VALUE
TaxF(t)  = tauprof(t)*(Y(t)-(1+tauF(t))*w(t)*LD(t)-tauprofdeduct(t)*(J(t)+delta*K(t)));
Div(t)   = Y(t)-(1+tauF(t))*w(t)*LD(t)-I(t)-J(t)-TaxF(t);
V(t)     = (1+r(t))/(r(t)-g)*Div(t);

% CONSUMPTION AND SAVINGS
yv(1,t)     = (1-tauW(t))*w(t)*part(t)*ell(t)*theta(t)+(1-part(t))*b(t)-taul(t);
ybar(t)     = yv(1,t)-dis_tot*pc(t);
yv(2,t)     = p(t)-taul(t);

Omegav(2,t) = 1/(1-(1/(1+rho))^sigma*((1+r(t))*pc(t)/pc(t))^(sigma-1)*gam(2,t));
Lambda(t)   = (Omegav(2,t)/Omegav(1,t))^(1/rho2);
Upsilon(t)  = omega + (1-omega)*Lambda(t)^(1-rho2);

hv(2,t)  = (1-G*gam(2,t)/(1+r(t)))^(-1)*yv(2,t);
hv(1,t)  = (1-G*omega*gam(1,t)/(Upsilon(t)*(1+r(t))))^(-1)*(ybar(t)+gam(1,t)*G/(Upsilon(t)*(1+r(t)))*(1-omega)*hv(2,t)*Lambda(t)^(1-rho2));

Hv(:,t)  = hv(:,t).*Nv(:,t);

Av(1,t)  = (1-(1+r(t))*omega/G*(1-Omegav(1,t)^(-1)))^(-1)*(1+r(t))*omega/G*(ybar(t)*Nv(1,t)-Omegav(1,t)^(-1)*Hv(1,t));
Q(t)     = (Av(1,t)+Hv(1,t))/(Omegav(1,t)*pc(t));
Cv(1,t)  = Q(t)+dis_tot*Nv(1,t);
Sav      = Av(1,t)+yv(1,t)*Nv(1,t)-pc(t)*Cv(1,t);

Av(2,t)  = (1-(1+r(t))/G*(1-Omegav(2,t)^(-1)))^(-1)*(1+r(t))/G*(yv(2,t)*Nv(2,t)-Omegav(2,t)^(-1)*Hv(2,t)+(1-omega)*Sav);
Cv(2,t)  = (Av(2,t)+Hv(2,t))/(Omegav(2,t)*pc(t));

% AGGREGATION
C(t)     = sum(Cv(:,t));
A(t)     = sum(Av(:,t));
sharev(:,t) = Av(:,t)./A(t);

% TRADE BALANCE AND FOREIGN ASSETS
TB(t)    = -DF(t)*(r(t)-g)/(1+r(t));

% GOVERNMENT
Exp(t)   = CG(t)+(1-part(t))*b(t)*Nv(1,t)+p(t)*Nv(2,t);
Rev(t)   = TaxF(t)+(tauF(t)*LD(t)+tauW(t)*LS(t))*w(t)+taul(t)*N(t)+tauC(t)*C(t);
PB(t)    = DG(t)*(r(t)-g)/(1+r(t));

% EXCESS DEMANDS
edy(t)   = I(t)+J(t)+C(t)+CG(t)+TB(t)-Y(t);
edl(t)   = LD(t)-LS(t);
edg(t)   = Rev(t)-Exp(t)-PB(t);
eda(t)   = DF(t)+DG(t)+V(t)-A(t);
edOmega  = 1/(1-(1/(1+rho))^sigma*((1+r(t))*Upsilon(t)*pc(t)/pc(t))^(sigma-1)*gam(1,t))-Omegav(1,t);

% WALRAS LAW
edv(t)   = edy(t)+w(t)*edl(t)+(r(t)-g)/(1+r(t))*eda(t)+edg(t);
if abs(edv(t))> 1e-10; error('Error in SS.m: Walras Law does not hold!'); end

resid(1,1) = edy(t);
resid(2,1) = edl(t);
resid(3,1) = edg(t);
resid(4,1) = edOmega;

end