% ----------------------
% calib.m
% ----------------------
% calibrates the model
% ----------------------

% DATA AND CALIBRATION

global alpha A_0 K0 LS0 LD0 I0 J0 Div0 V0 Hv0 hv0 A0 Omegav0 Q0 C0 TB0
global parl0 parl1 parp0 hcut0 ybar0 yv0 Cv0 sharev0 Av0 Upsilon0 Lambda0
global pc0 TaxF0 Exp0 Rev0 PB0 DG0

% force column vector
Omegav0 = zeros(2,1); sharev0 = zeros(2,1); Av0 = zeros(2,1);
Cv0 = zeros(2,1); hv0 = zeros(2,1); yv0 = zeros(2,1);

x0      = [0 0 0 10]; % inital guess
[x1, retcode] = findroot(@findcalib,x0');
if retcode~=0 error('Root finder in calib did not converge!'); end

global DF0 cG0 CG0 taul0 edy0 edl0 edg0
DF0     = x1(1);
cG0     = x1(2); CG0 = cG0*N0;
edy0    = I0+J0+C0+CG0+TB0-Y0;
edl0    = LD0-LS0;
edg0    = Rev0-Exp0-PB0;

fprintf('CHECK CALIBRATION: \t %4.5f\n',sum(abs([edy0,edl0,edg0])));

% TIME SERIES INITIALIZATIONS

global Y Div w I J V K Hv A Omegav edl Q C TB DF edy N ell LS LD 
global part hcut ybar p Lambda Upsilon Av Cv hv yv sharev
global NB Nv r gam theta
global tauW tauF taul tauprof tauprofdeduct tauC b CG cG
global pc TaxF Exp Rev PB DG DGtarget edg eda edv

Y       = zeros(1,tend); Div = Y; w = Y; I = Y; J = Y; V = Y; CG = Y;
K       = Y; A = Y; Q = Y; C = Y; TB = Y; DF = Y; edy = Y; eda = Y;
N       = Y; L = Y; ell = Y; LS = Y; LD = Y; edl = Y; edv = Y;
part    = Y; hcut = Y; ybar = Y; TaxF = Y; Exp = Y; Rev = Y; PB = Y; edg = Y;
Lambda  = Y; Upsilon = Y;

Hv = zeros(2,tend); Av = Hv; Cv = Hv; hv = Hv; yv = Hv;

r       = r0*ones(1,tend); Hv = zeros(2,tend);
NB      = NB0*ones(1,tend); theta = theta0*ones(1,tend);
tauW    = tauW0*ones(1,tend); tauF = tauF0*ones(1,tend);
taul    = taul0*ones(1,tend); tauprof = tauprof0*ones(1,tend);
tauprofdeduct = tauprofdeduct0*ones(1,tend); tauC = tauC0*ones(1,tend);
pc      = pc0*ones(1,tend); b = b0*ones(1,tend); p = p0*ones(1,tend);
cG      = cG0*ones(1,tend); DG = DG0*ones(1,tend); DGtarget = DG0*ones(1,tend);

Nv      = kron(Nv0,ones(1,tend)); gam = kron(gam0,ones(1,tend));
sharev  = kron(sharev0,ones(1,tend)); Omegav = kron(Omegav0,ones(1,tend));

% CHECK SETTINGS
if (rem(budget_bal,1)~=0||budget_bal<1||budget_bal>6)
    error('Error: Enter a budget_bal between 1 and 6'); end

% REPLICATE INTIAL CALIBRATION
x0SS    = ones(4,1); x0TE = ones(2,1);
t       = 1; fprintf('\nREPLICATE SS: \t\t %4.5f\n', sum(abs(SS(x0SS))));
t       = 2; sum(abs(SS(x0SS)));
t       = 1; fprintf('REPLICATE TE: \t\t %4.5f\n\n', sum(abs(TE(x0TE))));

% TAKE INITIAL STEADY STATE AS GUESS FOR JACOBIAN

guess   = kron([V(t) hv(:,t)' Omegav(:,t)'],ones(tend,1));
