% ----------------------
% findcalib.m
% ----------------------
% computes calibration
% in:   foreignassets
% out:  resid
% ----------------------

function resid = findcalib(inputs)

    global gam0 omega r0 rho g G sigma rho2 psi delta ell0 w0 theta0 N0 Nv0 Y0 
    global A_0 alpha Hv0 A0 K0 LS0 LD0 I0 J0 Div0 V0 Q0 C0 TB0
    global epsl parl0 parl1 parp0 epsp hcut0 part0 ybar0 yv0 hv0
    global tauW0 tauF0 tauprof0 tauprofdeduct0 tauC0 b0
    global pc0 p0 TaxF0 Exp0 Rev0 PB0 DG0 Lambda0 Upsilon0 
    global sharev0 Av0 Cv0 Omegav0 taul0
    
    DF0        = inputs(1);
    cG0        = inputs(2);
    taul0      = inputs(3);
    Omegav0(1) = inputs(4);
            
    pc0     = 1+tauC0;
    
    % CALIBRATION OF LABOR SUPPLY MARGINS
    
    % set parl0 in order to reprodcue ell0, FOC ell0
    parl0   = ((1-tauW0)*w0*theta0/pc0)/ell0^(1/epsl);
    % set parl1 in order to normalize effort costs to 0
    parl1   = parl0*(epsl/(1+epsl))*ell0^((1+epsl)/epsl);
    dis_ell = parl0*(epsl/(1+epsl))*ell0^((1+epsl)/epsl)-parl1;
    
    hcut0   = ((1-tauW0)*w0*theta0*ell0-b0)/pc0-dis_ell;
    % set parp0 in order to reprodce part0
    parp0   = ((1-part0)/hcut0^(-epsp))^(1/epsp);
    hexp    = 1/part0*epsp/(1+epsp)*(parp0^epsp*hcut0^(1-epsp)-parp0);
    dis_tot = part0*dis_ell-(1-part0)*hexp;
    
    LS0     = part0*ell0*theta0*Nv0(1);
    LD0     = LS0;
    uck     = (r0+delta*(1-tauprofdeduct0*tauprof0))/(1-tauprof0);
    K0      = (Y0-(1+tauF0)*w0*LD0)/uck;
    I0      = (delta+g)*K0;
    J0      = 1/2*psi*K0*(I0/K0-delta-g)^2;
    alpha   = uck*K0/Y0;
    A_0     = Y0/(K0^alpha*LS0^(1-alpha));
    LD0     = ((1-alpha)*A_0/((1+tauF0)*w0))^(1/alpha)*K0;
    TaxF0   = tauprof0*(Y0-(1+tauF0)*w0*LD0-tauprofdeduct0*(J0+delta*K0));
    Div0    = Y0-(1+tauF0)*w0*LD0-I0-J0-TaxF0;
    V0      = (1+r0)*Div0/(r0-g);
    
    yv0(1)  = (1-tauW0)*w0*part0*ell0*theta0+(1-part0)*b0-taul0;
    ybar0   = yv0(1)-dis_tot*pc0;
    yv0(2)  = p0-taul0;
    
    Omegav0(2)  = 1/(1-(1/(1+rho))^sigma*((1+r0)*pc0/pc0)^(sigma-1)*gam0(2));
    Lambda0     = (Omegav0(2)/Omegav0(1))^(1/rho2);
    Upsilon0    = omega + (1-omega)*Lambda0^(1-rho2);
    
    hv0(2)  = (1-G*gam0(2)/(1+r0))^(-1)*yv0(2);
    hv0(1)  = (1-G*omega*gam0(1)/(Upsilon0*(1+r0)))^(-1)*(ybar0+gam0(1)*G/(Upsilon0*(1+r0))*(1-omega)*hv0(2)*Lambda0^(1-rho2));

    Hv0     = hv0.*Nv0;

    Av0(1)   = (1-(1+r0)*omega/G*(1-Omegav0(1)^(-1)))^(-1)*(1+r0)*omega/G*(ybar0*Nv0(1)-Omegav0(1)^(-1)*Hv0(1));
    Q0       = (Av0(1)+Hv0(1))/(Omegav0(1)*pc0);
    Cv0(1)   = Q0+dis_tot*Nv0(1);
    Sav      = Av0(1)+yv0(1).*Nv0(1)-pc0*Cv0(1);

    Av0(2)   = (1-(1+r0)/G*(1-Omegav0(2)^(-1)))^(-1)*(1+r0)/G*(yv0(2)*Nv0(2)-Omegav0(2)^(-1)*Hv0(2)+(1-omega)*Sav);
    Cv0(2)   = (Av0(2)+Hv0(2))/(Omegav0(2)*pc0);
    
    A0       = Av0(1)+Av0(2);
    sharev0  = Av0./A0;
      
    Cguess  = Cv0(1)+Cv0(2);
        
    TB0     = -DF0*(r0-g)/(1+r0);
    Exp0    = cG0*N0+(1-part0)*b0*Nv0(1)+p0*Nv0(2);
    Rev0    = TaxF0+(tauF0*LD0+tauW0*LS0)*w0+taul0*N0+tauC0*C0;
    PB0     = DG0*(r0-g)/(1+r0);
    
    eda     = DF0+DG0+V0-A0;
    
    edOmega = 1/(1-(1/(1+rho))^sigma*((1+r0)*Upsilon0*pc0/pc0)^(sigma-1)*gam0(1))-Omegav0(1);
        
    resid(1,1)   = I0+J0+C0+cG0*N0+TB0-Y0;
    resid(2,1)   = Rev0-Exp0-PB0;
    resid(3,1)   = Cguess-C0;
    resid(4,1)   = edOmega;
    
end