% ----------------------
% param.m
% ----------------------
% loads exogenous parameters
% ----------------------

global gam0 omega rho r0 g G delta sigma rho2 epsl epsp

gam0    = [0.99 0.94]';         % surivival probability
omega   = 1-1/40;               % aging probability
rho     = .035;                 % discount rate
r0      = .03;                  % interest rate
g       = 0.01;                 % exogenous growth rate
G       = 1+g;                  % exogenous growth factor
delta   = 0.1;                  % depreciation rate
sigma   = 0.25;                 % intertemporal elasticity of substitution
rho2    = (sigma-1)/sigma;
epsl    = 0.3;                  % labor supply elasticity (hours)
epsp    = 0.5;                  % participation elasticity

global L0 w0 theta0 N0 NB0 Nv0 Y0 C0 psi ell0 part0

L0      = 30;                   % total labor supply in eff. units
w0      = 2;                    % wage rate
theta0  = 1;                    % labor productivity parameter
N0      = 100;                  % noramlized population size
help1   = (1+gam0(1)*(1-omega)/(1-gam0(2)))/(1-gam0(1)*omega);
NB0     = N0/help1;             % newborns
Nv0     = zeros(2,1);
Nv0(1)  = NB0/(1-gam0(1)*omega);                    % workers
Nv0(2)  = gam0(1)*(1-omega)/(1-gam0(2))*Nv0(1);     % retirees
Y0      = 100;                  % normalized output
C0      = 0.6*Y0;               % consumption share (calibrated using taul0)
psi     = 10;                   % scaling factor adjustment costs
part0   = 0.7;                  % participation rate
ell0    = L0/(Nv0(1)*theta0*part0); % per capita labor supply

global tauW0 tauF0 tauprof0 taul0 tauprofdeduct0 tauC0 b0 p0 DG0 t

tauW0   = 0.1;                  % wage tax employee
tauF0   = 0.1;                  % wage tax employer
tauC0   = 0.1;                  % consumption tax
tauprof0= 0.1;                  % profit tax
tauprofdeduct0 = 1;             % capital maintenance costs deductible
b0      = 0.5*(1-tauW0)*w0*ell0*theta0;   % non-work benefits
p0      = 0.3*(1-tauW0)*w0*ell0*theta0;   % pension benefits
DG0     = 0.6*Y0;               % government debt level
% G0 is used to balance budget in calibration
% Define all taxes at least slightly > 0

t       = 1;                    % time index

