% ----------------------
% path.m
% ----------------------
% computes the path of temporary equilibrium until tend
% in:   guess, tstart (opt), tstop (opt)
% out:  actual
% ----------------------

function actualout = path(guessin,tstart,tstop)

global t tend w0 tauW0 tauF0 tauC0 tauprof0 taul0 cG0
global w tauW tauF tauC tauprof taul cG budget_bal
global V hv Omegav

V        = guessin(:,1)';
hv       = guessin(:,2:3)';
Omegav   = guessin(:,4:5)';

% COMPUTE ALL TEMPORARY EQUILIBRIA

if nargin < 3;
    tstop = tend;
end

if nargin > 1
    t = tstart;
else
    t = 1;
end

x0TE = ones(2,1);

while t < tstop
    
    if t > 1
        x0TE(1)      = w(t-1)/w0;
        % budget-instrument choice
        if budget_bal == 1; x0TE(2) = tauW(t-1)/tauW0; end
        if budget_bal == 2; x0TE(2) = tauF(t-1)/tauF0; end
        if budget_bal == 3; x0TE(2) = tauC(t-1)/tauC0; end
        if budget_bal == 4; x0TE(2) = taul(t-1)/taul0; end
        if budget_bal == 5; x0TE(2) = tauprof(t-1)/tauprof0; end
        if budget_bal == 6; x0TE(2) = cG(t-1)/cG0; end
    end
    
    [x1, retcode] = findroot(@TE,x0TE);
    
    if retcode~=0 error('Root finder in path did not converge!'); end
    
    t   = t+1;
end

actual = [V; hv; Omegav]';

actualout = actual;

end